"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.datatransfer.v1.endpoint_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TransferType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TransferTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TransferType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRANSFER_TYPE_UNSPECIFIED: _TransferType.ValueType  # 0
    SNAPSHOT_AND_INCREMENT: _TransferType.ValueType  # 1
    """Snapshot and increment"""
    SNAPSHOT_ONLY: _TransferType.ValueType  # 2
    """Snapshot"""
    INCREMENT_ONLY: _TransferType.ValueType  # 3
    """Increment"""

class TransferType(_TransferType, metaclass=_TransferTypeEnumTypeWrapper): ...

TRANSFER_TYPE_UNSPECIFIED: TransferType.ValueType  # 0
SNAPSHOT_AND_INCREMENT: TransferType.ValueType  # 1
"""Snapshot and increment"""
SNAPSHOT_ONLY: TransferType.ValueType  # 2
"""Snapshot"""
INCREMENT_ONLY: TransferType.ValueType  # 3
"""Increment"""
global___TransferType = TransferType

class _TransferStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TransferStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TransferStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRANSFER_STATUS_UNSPECIFIED: _TransferStatus.ValueType  # 0
    CREATING: _TransferStatus.ValueType  # 1
    """Transfer does some work before running"""
    CREATED: _TransferStatus.ValueType  # 2
    """Transfer created but not started by user"""
    RUNNING: _TransferStatus.ValueType  # 3
    """Transfer currently doing replication work"""
    STOPPING: _TransferStatus.ValueType  # 4
    """Transfer shutdown"""
    STOPPED: _TransferStatus.ValueType  # 5
    """Transfer stopped by user"""
    ERROR: _TransferStatus.ValueType  # 6
    """Transfer stopped by system"""
    SNAPSHOTTING: _TransferStatus.ValueType  # 7
    """Transfer copy snapshot"""
    DONE: _TransferStatus.ValueType  # 8
    """Transfer reach terminal phase"""

class TransferStatus(_TransferStatus, metaclass=_TransferStatusEnumTypeWrapper): ...

TRANSFER_STATUS_UNSPECIFIED: TransferStatus.ValueType  # 0
CREATING: TransferStatus.ValueType  # 1
"""Transfer does some work before running"""
CREATED: TransferStatus.ValueType  # 2
"""Transfer created but not started by user"""
RUNNING: TransferStatus.ValueType  # 3
"""Transfer currently doing replication work"""
STOPPING: TransferStatus.ValueType  # 4
"""Transfer shutdown"""
STOPPED: TransferStatus.ValueType  # 5
"""Transfer stopped by user"""
ERROR: TransferStatus.ValueType  # 6
"""Transfer stopped by system"""
SNAPSHOTTING: TransferStatus.ValueType  # 7
"""Transfer copy snapshot"""
DONE: TransferStatus.ValueType  # 8
"""Transfer reach terminal phase"""
global___TransferStatus = TransferStatus

@typing.final
class Transfer(google.protobuf.message.Message):
    """Transfer core entity"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    WARNING_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    DATA_OBJECTS_FIELD_NUMBER: builtins.int
    PRESTABLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    status: global___TransferStatus.ValueType
    type: global___TransferType.ValueType
    warning: builtins.str
    prestable: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def source(self) -> yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint: ...
    @property
    def target(self) -> yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint: ...
    @property
    def runtime(self) -> global___Runtime: ...
    @property
    def transformation(self) -> global___Transformation: ...
    @property
    def data_objects(self) -> global___DataObjects: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        source: yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint | None = ...,
        target: yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint | None = ...,
        runtime: global___Runtime | None = ...,
        status: global___TransferStatus.ValueType = ...,
        type: global___TransferType.ValueType = ...,
        warning: builtins.str = ...,
        transformation: global___Transformation | None = ...,
        data_objects: global___DataObjects | None = ...,
        prestable: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data_objects", b"data_objects", "runtime", b"runtime", "source", b"source", "target", b"target", "transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data_objects", b"data_objects", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "prestable", b"prestable", "runtime", b"runtime", "source", b"source", "status", b"status", "target", b"target", "transformation", b"transformation", "type", b"type", "warning", b"warning"]) -> None: ...

global___Transfer = Transfer

@typing.final
class Runtime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    YC_RUNTIME_FIELD_NUMBER: builtins.int
    @property
    def yc_runtime(self) -> global___YcRuntime: ...
    def __init__(
        self,
        *,
        yc_runtime: global___YcRuntime | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["runtime", b"runtime", "yc_runtime", b"yc_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["runtime", b"runtime", "yc_runtime", b"yc_runtime"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["runtime", b"runtime"]) -> typing.Literal["yc_runtime"] | None: ...

global___Runtime = Runtime

@typing.final
class ShardingUploadParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_COUNT_FIELD_NUMBER: builtins.int
    PROCESS_COUNT_FIELD_NUMBER: builtins.int
    job_count: builtins.int
    process_count: builtins.int
    def __init__(
        self,
        *,
        job_count: builtins.int = ...,
        process_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["job_count", b"job_count", "process_count", b"process_count"]) -> None: ...

global___ShardingUploadParams = ShardingUploadParams

@typing.final
class YcRuntime(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_COUNT_FIELD_NUMBER: builtins.int
    UPLOAD_SHARD_PARAMS_FIELD_NUMBER: builtins.int
    job_count: builtins.int
    @property
    def upload_shard_params(self) -> global___ShardingUploadParams: ...
    def __init__(
        self,
        *,
        job_count: builtins.int = ...,
        upload_shard_params: global___ShardingUploadParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["upload_shard_params", b"upload_shard_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["job_count", b"job_count", "upload_shard_params", b"upload_shard_params"]) -> None: ...

global___YcRuntime = YcRuntime

@typing.final
class MaskFunction(google.protobuf.message.Message):
    """Mask function"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MASK_FUNCTION_HASH_FIELD_NUMBER: builtins.int
    @property
    def mask_function_hash(self) -> global___MaskFunctionHash:
        """Hash mask function"""

    def __init__(
        self,
        *,
        mask_function_hash: global___MaskFunctionHash | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mask_function", b"mask_function", "mask_function_hash", b"mask_function_hash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mask_function", b"mask_function", "mask_function_hash", b"mask_function_hash"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["mask_function", b"mask_function"]) -> typing.Literal["mask_function_hash"] | None: ...

global___MaskFunction = MaskFunction

@typing.final
class MaskFunctionHash(google.protobuf.message.Message):
    """Hash data using HMAC"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_DEFINED_SALT_FIELD_NUMBER: builtins.int
    user_defined_salt: builtins.str
    """This string will be used in the HMAC(sha256, salt) function applied to the
    column data.
    """
    def __init__(
        self,
        *,
        user_defined_salt: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_defined_salt", b"user_defined_salt"]) -> None: ...

global___MaskFunctionHash = MaskFunctionHash

@typing.final
class TablesFilter(google.protobuf.message.Message):
    """Filter tables using lists of included and excluded tables."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_TABLES_FIELD_NUMBER: builtins.int
    EXCLUDE_TABLES_FIELD_NUMBER: builtins.int
    @property
    def include_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of tables that will be included to transfer"""

    @property
    def exclude_tables(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of tables that will be excluded to transfer"""

    def __init__(
        self,
        *,
        include_tables: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_tables: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exclude_tables", b"exclude_tables", "include_tables", b"include_tables"]) -> None: ...

global___TablesFilter = TablesFilter

@typing.final
class ColumnsFilter(google.protobuf.message.Message):
    """Filter columns using lists of included and excluded columns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_COLUMNS_FIELD_NUMBER: builtins.int
    EXCLUDE_COLUMNS_FIELD_NUMBER: builtins.int
    @property
    def include_columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of columns that will be included to transfer"""

    @property
    def exclude_columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of columns that will be excluded to transfer"""

    def __init__(
        self,
        *,
        include_columns: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_columns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exclude_columns", b"exclude_columns", "include_columns", b"include_columns"]) -> None: ...

global___ColumnsFilter = ColumnsFilter

@typing.final
class MaskFieldTransformer(google.protobuf.message.Message):
    """Mask field transformer allows you to hash data"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Specify the name of the column for data masking (a regular expression)."""

    @property
    def function(self) -> global___MaskFunction:
        """Mask function"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
        function: global___MaskFunction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["function", b"function", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "function", b"function", "tables", b"tables"]) -> None: ...

global___MaskFieldTransformer = MaskFieldTransformer

@typing.final
class FilterColumnsTransformer(google.protobuf.message.Message):
    """Set up a list of table columns to transfer"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of the tables to filter using lists of included and excluded tables."""

    @property
    def columns(self) -> global___ColumnsFilter:
        """List of the columns to transfer to the target tables using lists of included and
        excluded columns.
        """

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: global___ColumnsFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> None: ...

global___FilterColumnsTransformer = FilterColumnsTransformer

@typing.final
class Table(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_SPACE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    name_space: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        name_space: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "name_space", b"name_space"]) -> None: ...

global___Table = Table

@typing.final
class RenameTable(google.protobuf.message.Message):
    """Specify rule for renaming table"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINAL_NAME_FIELD_NUMBER: builtins.int
    NEW_NAME_FIELD_NUMBER: builtins.int
    @property
    def original_name(self) -> global___Table:
        """Specify the current names of the table in the source"""

    @property
    def new_name(self) -> global___Table:
        """Specify the new names for this table in the target"""

    def __init__(
        self,
        *,
        original_name: global___Table | None = ...,
        new_name: global___Table | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["new_name", b"new_name", "original_name", b"original_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["new_name", b"new_name", "original_name", b"original_name"]) -> None: ...

global___RenameTable = RenameTable

@typing.final
class RenameTablesTransformer(google.protobuf.message.Message):
    """Set rules for renaming tables by specifying the current names of the tables in
    the source and new names for these tables in the target.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RENAME_TABLES_FIELD_NUMBER: builtins.int
    @property
    def rename_tables(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RenameTable]:
        """List of renaming rules"""

    def __init__(
        self,
        *,
        rename_tables: collections.abc.Iterable[global___RenameTable] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rename_tables", b"rename_tables"]) -> None: ...

global___RenameTablesTransformer = RenameTablesTransformer

@typing.final
class ReplacePrimaryKeyTransformer(google.protobuf.message.Message):
    """Override primary keys"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of columns to be used as primary keys"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["keys", b"keys", "tables", b"tables"]) -> None: ...

global___ReplacePrimaryKeyTransformer = ReplacePrimaryKeyTransformer

@typing.final
class ToStringTransformer(google.protobuf.message.Message):
    """Convert column values to strings
    The values will be converted depending on the source type
    Conversion rules are described here:
    https://cloud.yandex.com/en/docs/data-transfer/concepts/data-transformation#convert-to-string
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> global___ColumnsFilter:
        """List of included and excluded columns"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: global___ColumnsFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> None: ...

global___ToStringTransformer = ToStringTransformer

@typing.final
class SharderTransformer(google.protobuf.message.Message):
    """Set the number of shards for particular tables and a list of columns whose
    values will be used for calculating a hash to determine a shard.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    SHARDS_COUNT_FIELD_NUMBER: builtins.int
    shards_count: builtins.int
    """Number of shards"""
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> global___ColumnsFilter:
        """List of included and excluded columns"""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: global___ColumnsFilter | None = ...,
        shards_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["columns", b"columns", "tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "shards_count", b"shards_count", "tables", b"tables"]) -> None: ...

global___SharderTransformer = SharderTransformer

@typing.final
class TableSplitterTransformer(google.protobuf.message.Message):
    """A transfer splits the X table into multiple tables (X_1, X_2, ..., X_n) based on
    data.
    If a row was located in the X table before it was split, it is now in the X_i
    table,
    where i is determined by the column list and split string parameters.
    Example:
    If the column list has two columns, month of birth and gender, specified and the
    split string states @,
    information about an employee whose name is John and who was born on February
    11, 1984,
    from the Employees table will get to a new table named Employees@February@male.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    SPLITTER_FIELD_NUMBER: builtins.int
    splitter: builtins.str
    """Specify the split string to be used for merging components in a new table name."""
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables"""

    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Specify the columns in the tables to be partitioned."""

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
        splitter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "splitter", b"splitter", "tables", b"tables"]) -> None: ...

global___TableSplitterTransformer = TableSplitterTransformer

@typing.final
class FilterRowsTransformer(google.protobuf.message.Message):
    """This filter only applies to transfers with queues (Logbroker or Apache Kafka®)
    as a data source.
    When running a transfer, only the strings meeting the specified criteria remain
    in a changefeed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLES_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    filter: builtins.str
    """Filtering criterion. This can be comparison operators for numeric, string, and
    Boolean values,
    comparison to NULL, and checking whether a substring is part of a string.
    Details here:
    https://yandex.cloud/en-ru/docs/data-transfer/concepts/data-transformation#append-only-sources.
    Deprecated: Use filters instead.
    """
    @property
    def tables(self) -> global___TablesFilter:
        """List of included and excluded tables."""

    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Data is transported if it satisfies at least one of filters. Consider that there
        is OR statement between filters.
        Each filter can be comparison operators for numeric, string, and Boolean values,
        comparison to NULL, and
        checking whether a substring is part of a string.
        Details in docs:
        https://yandex.cloud/en-ru/docs/data-transfer/concepts/data-transformation#append-only-sources.
        """

    def __init__(
        self,
        *,
        tables: global___TablesFilter | None = ...,
        filter: builtins.str = ...,
        filters: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["tables", b"tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "filters", b"filters", "tables", b"tables"]) -> None: ...

global___FilterRowsTransformer = FilterRowsTransformer

@typing.final
class Transformer(google.protobuf.message.Message):
    """Some transformers may have limitations and only apply to some source-target
    pairs.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MASK_FIELD_FIELD_NUMBER: builtins.int
    FILTER_COLUMNS_FIELD_NUMBER: builtins.int
    RENAME_TABLES_FIELD_NUMBER: builtins.int
    REPLACE_PRIMARY_KEY_FIELD_NUMBER: builtins.int
    CONVERT_TO_STRING_FIELD_NUMBER: builtins.int
    SHARDER_TRANSFORMER_FIELD_NUMBER: builtins.int
    TABLE_SPLITTER_TRANSFORMER_FIELD_NUMBER: builtins.int
    FILTER_ROWS_FIELD_NUMBER: builtins.int
    @property
    def mask_field(self) -> global___MaskFieldTransformer: ...
    @property
    def filter_columns(self) -> global___FilterColumnsTransformer: ...
    @property
    def rename_tables(self) -> global___RenameTablesTransformer: ...
    @property
    def replace_primary_key(self) -> global___ReplacePrimaryKeyTransformer: ...
    @property
    def convert_to_string(self) -> global___ToStringTransformer: ...
    @property
    def sharder_transformer(self) -> global___SharderTransformer: ...
    @property
    def table_splitter_transformer(self) -> global___TableSplitterTransformer: ...
    @property
    def filter_rows(self) -> global___FilterRowsTransformer: ...
    def __init__(
        self,
        *,
        mask_field: global___MaskFieldTransformer | None = ...,
        filter_columns: global___FilterColumnsTransformer | None = ...,
        rename_tables: global___RenameTablesTransformer | None = ...,
        replace_primary_key: global___ReplacePrimaryKeyTransformer | None = ...,
        convert_to_string: global___ToStringTransformer | None = ...,
        sharder_transformer: global___SharderTransformer | None = ...,
        table_splitter_transformer: global___TableSplitterTransformer | None = ...,
        filter_rows: global___FilterRowsTransformer | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["convert_to_string", b"convert_to_string", "filter_columns", b"filter_columns", "filter_rows", b"filter_rows", "mask_field", b"mask_field", "rename_tables", b"rename_tables", "replace_primary_key", b"replace_primary_key", "sharder_transformer", b"sharder_transformer", "table_splitter_transformer", b"table_splitter_transformer", "transformer", b"transformer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["convert_to_string", b"convert_to_string", "filter_columns", b"filter_columns", "filter_rows", b"filter_rows", "mask_field", b"mask_field", "rename_tables", b"rename_tables", "replace_primary_key", b"replace_primary_key", "sharder_transformer", b"sharder_transformer", "table_splitter_transformer", b"table_splitter_transformer", "transformer", b"transformer"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["transformer", b"transformer"]) -> typing.Literal["mask_field", "filter_columns", "rename_tables", "replace_primary_key", "convert_to_string", "sharder_transformer", "table_splitter_transformer", "filter_rows"] | None: ...

global___Transformer = Transformer

@typing.final
class Transformation(google.protobuf.message.Message):
    """Transformation is converting data using special transformer functions.
    These functions are executed on a data stream, applied to each data change item,
    and transform them.
    A transformer can be run at both the metadata and data levels.
    Data can only be transformed if the source and target are of different types.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRANSFORMERS_FIELD_NUMBER: builtins.int
    @property
    def transformers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Transformer]:
        """Transformers are set as a list.
        When activating a transfer, a transformation plan is made for the tables that
        match the specified criteria.
        Transformers are applied to the tables in the sequence specified in the list.
        """

    def __init__(
        self,
        *,
        transformers: collections.abc.Iterable[global___Transformer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["transformers", b"transformers"]) -> None: ...

global___Transformation = Transformation

@typing.final
class DataObjects(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def include_objects(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        include_objects: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["include_objects", b"include_objects"]) -> None: ...

global___DataObjects = DataObjects



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.video.v1.manifest_pb2
import yandex.cloud.video.v1.video_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___GetVideoRequest = GetVideoRequest

@typing.final
class ListVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    page_size: builtins.int
    """The maximum number of the results per page to return.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "<field> <order>" (e.g. "createdAt desc").
    Default: "id asc".
    Possible fields: ["id", "title", "createdAt", "updatedAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """Filter expression that filters resources listed in the response.
    Expressions are composed of terms connected by logic operators.
    If value contains spaces or quotes,
    it should be in quotes (`'` or `"`) with the inner quotes being backslash escaped.
    Example: "key1='value' AND key2='value'".
    Supported operators: ["AND", "OR"].
    Supported fields: ["id", "title", "status", "visibilityStatus"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "filter", b"filter", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListVideoRequest = ListVideoRequest

@typing.final
class ListVideoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEOS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def videos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.video_pb2.Video]: ...
    def __init__(
        self,
        *,
        videos: collections.abc.Iterable[yandex.cloud.video.v1.video_pb2.Video] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "videos", b"videos"]) -> None: ...

global___ListVideoResponse = ListVideoResponse

@typing.final
class BatchGetVideosRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    VIDEO_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of requested video IDs."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "video_ids", b"video_ids"]) -> None: ...

global___BatchGetVideosRequest = BatchGetVideosRequest

@typing.final
class BatchGetVideosResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEOS_FIELD_NUMBER: builtins.int
    @property
    def videos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.video_pb2.Video]:
        """List of videos for channel."""

    def __init__(
        self,
        *,
        videos: collections.abc.Iterable[yandex.cloud.video.v1.video_pb2.Video] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["videos", b"videos"]) -> None: ...

global___BatchGetVideosResponse = BatchGetVideosResponse

@typing.final
class CreateVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    AUTO_TRANSCODE_FIELD_NUMBER: builtins.int
    AUTO_PUBLISH_FIELD_NUMBER: builtins.int
    ENABLE_AD_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TUSD_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    title: builtins.str
    """Video title."""
    description: builtins.str
    """Video description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType
    """Auto start transcoding."""
    @property
    def auto_publish(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Automatically publish video after transcoding.
        Switches visibility status to PUBLISHED.
        """

    @property
    def enable_ad(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enable advertisement for this video.
        Default: true.
        Set explicitly to false to disable advertisements for a specific video.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def tusd(self) -> global___VideoTUSDParams:
        """Upload video using the tus protocol."""

    @property
    def public_access(self) -> global___VideoPublicAccessParams:
        """Publicly accessible video available for viewing by anyone with the direct link.
        No additional authorization or access control is applied.
        """

    @property
    def sign_url_access(self) -> global___VideoSignURLAccessParams:
        """Checking access rights using url's signature."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType = ...,
        auto_publish: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        enable_ad: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tusd: global___VideoTUSDParams | None = ...,
        public_access: global___VideoPublicAccessParams | None = ...,
        sign_url_access: global___VideoSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_publish", b"auto_publish", "enable_ad", b"enable_ad", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "tusd", b"tusd"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_publish", b"auto_publish", "auto_transcode", b"auto_transcode", "channel_id", b"channel_id", "description", b"description", "enable_ad", b"enable_ad", "labels", b"labels", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "source", b"source", "thumbnail_id", b"thumbnail_id", "title", b"title", "tusd", b"tusd"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["tusd"] | None: ...

global___CreateVideoRequest = CreateVideoRequest

@typing.final
class VideoTUSDParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_SIZE_FIELD_NUMBER: builtins.int
    FILE_NAME_FIELD_NUMBER: builtins.int
    file_size: builtins.int
    """File size."""
    file_name: builtins.str
    """File name."""
    def __init__(
        self,
        *,
        file_size: builtins.int = ...,
        file_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_name", b"file_name", "file_size", b"file_size"]) -> None: ...

global___VideoTUSDParams = VideoTUSDParams

@typing.final
class VideoPublicAccessParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoPublicAccessParams = VideoPublicAccessParams

@typing.final
class VideoSignURLAccessParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoSignURLAccessParams = VideoSignURLAccessParams

@typing.final
class CreateVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___CreateVideoMetadata = CreateVideoMetadata

@typing.final
class UpdateVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    VIDEO_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    AUTO_TRANSCODE_FIELD_NUMBER: builtins.int
    ENABLE_AD_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    SIGN_URL_ACCESS_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    title: builtins.str
    """Video title."""
    description: builtins.str
    """Video description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType
    """Auto start transcoding."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the video are going to be updated."""

    @property
    def enable_ad(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enable advertisement for this video.
        Default: true.
        Use this to disable advertisement for a specific video.
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    @property
    def public_access(self) -> global___VideoPublicAccessParams:
        """Publicly accessible video available for viewing by anyone with the direct link.
        No additional authorization or access control is applied.
        """

    @property
    def sign_url_access(self) -> global___VideoSignURLAccessParams:
        """Checking access rights using url's signature."""

    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        auto_transcode: yandex.cloud.video.v1.video_pb2.AutoTranscode.ValueType = ...,
        enable_ad: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        public_access: global___VideoPublicAccessParams | None = ...,
        sign_url_access: global___VideoSignURLAccessParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "enable_ad", b"enable_ad", "field_mask", b"field_mask", "public_access", b"public_access", "sign_url_access", b"sign_url_access"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auto_transcode", b"auto_transcode", "description", b"description", "enable_ad", b"enable_ad", "field_mask", b"field_mask", "labels", b"labels", "public_access", b"public_access", "sign_url_access", b"sign_url_access", "thumbnail_id", b"thumbnail_id", "title", b"title", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "sign_url_access"] | None: ...

global___UpdateVideoRequest = UpdateVideoRequest

@typing.final
class UpdateVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___UpdateVideoMetadata = UpdateVideoMetadata

@typing.final
class TranscodeVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    SUBTITLE_IDS_FIELD_NUMBER: builtins.int
    TRANSLATION_SETTINGS_FIELD_NUMBER: builtins.int
    SUMMARIZATION_SETTINGS_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which transcoding specific fields of the video
        are going to be updated.
        """

    @property
    def subtitle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IDs of active manually uploaded video subtitles."""

    @property
    def translation_settings(self) -> global___VideoTranslationSettings:
        """Video translation settings."""

    @property
    def summarization_settings(self) -> global___VideoSummarizationSettings:
        """Video summarization settings."""

    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        field_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        subtitle_ids: collections.abc.Iterable[builtins.str] | None = ...,
        translation_settings: global___VideoTranslationSettings | None = ...,
        summarization_settings: global___VideoSummarizationSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_mask", b"field_mask", "summarization_settings", b"summarization_settings", "translation_settings", b"translation_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["field_mask", b"field_mask", "subtitle_ids", b"subtitle_ids", "summarization_settings", b"summarization_settings", "translation_settings", b"translation_settings", "video_id", b"video_id"]) -> None: ...

global___TranscodeVideoRequest = TranscodeVideoRequest

@typing.final
class VideoTranslationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TranslationTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INPUT_TRACK_FIELD_NUMBER: builtins.int
        SUBTITLES_FIELD_NUMBER: builtins.int
        AUDIO_FIELD_NUMBER: builtins.int
        @property
        def input_track(self) -> global___VideoTranslationSettings.InputTrack:
            """Input track settings."""

        @property
        def subtitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoTranslationSettings.SubtitleTrack]:
            """Settings for target subtitle tracks."""

        @property
        def audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoTranslationSettings.AudioTrack]:
            """Settings for target audio tracks."""

        def __init__(
            self,
            *,
            input_track: global___VideoTranslationSettings.InputTrack | None = ...,
            subtitles: collections.abc.Iterable[global___VideoTranslationSettings.SubtitleTrack] | None = ...,
            audio: collections.abc.Iterable[global___VideoTranslationSettings.AudioTrack] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["input_track", b"input_track"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["audio", b"audio", "input_track", b"input_track", "subtitles", b"subtitles"]) -> None: ...

    @typing.final
    class InputTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRACK_INDEX_FIELD_NUMBER: builtins.int
        SRC_LANG_FIELD_NUMBER: builtins.int
        track_index: builtins.int
        """Input audio track index (one-based)."""
        src_lang: builtins.str
        """Source track language in any of the following formats:
        * three-letter code according to ISO 639-2/T, ISO 639-2/B, or ISO 639-3 
        * two-letter code according to ISO 639-1                          
        Track language will be deduced automatically if not provided.
        In the latter case the deduction accuracy is not guaranteed.
        For better performance please do specify the source track language when possible.
        """
        def __init__(
            self,
            *,
            track_index: builtins.int = ...,
            src_lang: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["src_lang", b"src_lang", "track_index", b"track_index"]) -> None: ...

    @typing.final
    class SubtitleTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DST_LANG_FIELD_NUMBER: builtins.int
        LABEL_FIELD_NUMBER: builtins.int
        dst_lang: builtins.str
        """Target language in any of the following formats:
        * three-letter code according to ISO 639-2/T, ISO 639-2/B, or ISO 639-3 
        * two-letter code according to ISO 639-1
        """
        label: builtins.str
        """Track label to be displayed on the screen during video playback."""
        def __init__(
            self,
            *,
            dst_lang: builtins.str = ...,
            label: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["dst_lang", b"dst_lang", "label", b"label"]) -> None: ...

    @typing.final
    class AudioTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DST_LANG_FIELD_NUMBER: builtins.int
        LABEL_FIELD_NUMBER: builtins.int
        dst_lang: builtins.str
        """Target language in any of the following formats:
        * three-letter code according to ISO 639-2/T, ISO 639-2/B, or ISO 639-3 
        * two-letter code according to ISO 639-1
        """
        label: builtins.str
        """Track label to be displayed on the screen during video playback."""
        def __init__(
            self,
            *,
            dst_lang: builtins.str = ...,
            label: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["dst_lang", b"dst_lang", "label", b"label"]) -> None: ...

    TRACKS_FIELD_NUMBER: builtins.int
    @property
    def tracks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoTranslationSettings.TranslationTrack]:
        """Translation settings for each track."""

    def __init__(
        self,
        *,
        tracks: collections.abc.Iterable[global___VideoTranslationSettings.TranslationTrack] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tracks", b"tracks"]) -> None: ...

global___VideoTranslationSettings = VideoTranslationSettings

@typing.final
class VideoSummarizationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SummarizationTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INPUT_TRACK_FIELD_NUMBER: builtins.int
        @property
        def input_track(self) -> global___VideoSummarizationSettings.InputTrack:
            """Input track settings."""

        def __init__(
            self,
            *,
            input_track: global___VideoSummarizationSettings.InputTrack | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["input_track", b"input_track"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["input_track", b"input_track"]) -> None: ...

    @typing.final
    class InputTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TRACK_INDEX_FIELD_NUMBER: builtins.int
        SRC_LANG_FIELD_NUMBER: builtins.int
        track_index: builtins.int
        """Input audio track index (one-based)."""
        src_lang: builtins.str
        """Source track language (three-letter code according to ISO 639-2/T, ISO 639-2/B, or ISO 639-3).
        It will be deduced automatically if not provided.
        In the latter case the deduction accuracy is not guaranteed.
        For better performance please do specify the source track language when possible.
        """
        def __init__(
            self,
            *,
            track_index: builtins.int = ...,
            src_lang: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["src_lang", b"src_lang", "track_index", b"track_index"]) -> None: ...

    TRACKS_FIELD_NUMBER: builtins.int
    PROCESS_ALL_TRACKS_FIELD_NUMBER: builtins.int
    process_all_tracks: builtins.bool
    """Summarize all available tracks.
    If enabled, `tracks` parameter is ignored.
    Enables automatic source language deduction for each track
    and thus may lead to performance degradation.
    """
    @property
    def tracks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VideoSummarizationSettings.SummarizationTrack]:
        """Summarization settings for each track."""

    def __init__(
        self,
        *,
        tracks: collections.abc.Iterable[global___VideoSummarizationSettings.SummarizationTrack] | None = ...,
        process_all_tracks: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["process_all_tracks", b"process_all_tracks", "tracks", b"tracks"]) -> None: ...

global___VideoSummarizationSettings = VideoSummarizationSettings

@typing.final
class TranscodeVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___TranscodeVideoMetadata = TranscodeVideoMetadata

@typing.final
class DeleteVideoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___DeleteVideoRequest = DeleteVideoRequest

@typing.final
class DeleteVideoMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___DeleteVideoMetadata = DeleteVideoMetadata

@typing.final
class BatchDeleteVideosRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    VIDEO_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of video IDs."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "video_ids", b"video_ids"]) -> None: ...

global___BatchDeleteVideosRequest = BatchDeleteVideosRequest

@typing.final
class BatchDeleteVideosMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_IDS_FIELD_NUMBER: builtins.int
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of video IDs."""

    def __init__(
        self,
        *,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_ids", b"video_ids"]) -> None: ...

global___BatchDeleteVideosMetadata = BatchDeleteVideosMetadata

@typing.final
class PerformVideoActionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    PUBLISH_FIELD_NUMBER: builtins.int
    UNPUBLISH_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    @property
    def publish(self) -> global___PublishVideoAction: ...
    @property
    def unpublish(self) -> global___UnpublishVideoAction: ...
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        publish: global___PublishVideoAction | None = ...,
        unpublish: global___UnpublishVideoAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "unpublish", b"unpublish"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "publish", b"publish", "unpublish", b"unpublish", "video_id", b"video_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["publish", "unpublish"] | None: ...

global___PerformVideoActionRequest = PerformVideoActionRequest

@typing.final
class PublishVideoAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishVideoAction = PublishVideoAction

@typing.final
class UnpublishVideoAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnpublishVideoAction = UnpublishVideoAction

@typing.final
class PerformVideoActionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___PerformVideoActionMetadata = PerformVideoActionMetadata

@typing.final
class GetVideoPlayerURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    SIGNED_URL_EXPIRATION_DURATION_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    @property
    def params(self) -> global___VideoPlayerParams: ...
    @property
    def signed_url_expiration_duration(self) -> google.protobuf.duration_pb2.Duration:
        """Optional field, used to set custom url expiration duration for videos with sign_url_access"""

    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
        params: global___VideoPlayerParams | None = ...,
        signed_url_expiration_duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration", "video_id", b"video_id"]) -> None: ...

global___GetVideoPlayerURLRequest = GetVideoPlayerURLRequest

@typing.final
class VideoPlayerParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTE_FIELD_NUMBER: builtins.int
    AUTOPLAY_FIELD_NUMBER: builtins.int
    HIDDEN_FIELD_NUMBER: builtins.int
    mute: builtins.bool
    """If true, a player will be muted by default."""
    autoplay: builtins.bool
    """If true, playback will start automatically."""
    hidden: builtins.bool
    """If true, a player interface will be hidden by default."""
    def __init__(
        self,
        *,
        mute: builtins.bool = ...,
        autoplay: builtins.bool = ...,
        hidden: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["autoplay", b"autoplay", "hidden", b"hidden", "mute", b"mute"]) -> None: ...

global___VideoPlayerParams = VideoPlayerParams

@typing.final
class GetVideoPlayerURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URL_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    player_url: builtins.str
    """Direct link to the video."""
    html: builtins.str
    """HTML embed code in Iframe format."""
    def __init__(
        self,
        *,
        player_url: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["html", b"html", "player_url", b"player_url"]) -> None: ...

global___GetVideoPlayerURLResponse = GetVideoPlayerURLResponse

@typing.final
class BatchGetVideoPlayerURLsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    VIDEO_IDS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    SIGNED_URL_EXPIRATION_DURATION_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    @property
    def video_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of requested video IDs."""

    @property
    def params(self) -> global___VideoPlayerParams: ...
    @property
    def signed_url_expiration_duration(self) -> google.protobuf.duration_pb2.Duration:
        """Optional field, used to set custom url expiration duration for videos with sign_url_access"""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        video_ids: collections.abc.Iterable[builtins.str] | None = ...,
        params: global___VideoPlayerParams | None = ...,
        signed_url_expiration_duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "params", b"params", "signed_url_expiration_duration", b"signed_url_expiration_duration", "video_ids", b"video_ids"]) -> None: ...

global___BatchGetVideoPlayerURLsRequest = BatchGetVideoPlayerURLsRequest

@typing.final
class BatchGetVideoPlayerURLsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAYER_URLS_FIELD_NUMBER: builtins.int
    @property
    def player_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        player_urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["player_urls", b"player_urls"]) -> None: ...

global___BatchGetVideoPlayerURLsResponse = BatchGetVideoPlayerURLsResponse

@typing.final
class GetVideoManifestsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_ID_FIELD_NUMBER: builtins.int
    video_id: builtins.str
    """ID of the video."""
    def __init__(
        self,
        *,
        video_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["video_id", b"video_id"]) -> None: ...

global___GetVideoManifestsRequest = GetVideoManifestsRequest

@typing.final
class GetVideoManifestsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANIFESTS_FIELD_NUMBER: builtins.int
    @property
    def manifests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.manifest_pb2.Manifest]: ...
    def __init__(
        self,
        *,
        manifests: collections.abc.Iterable[yandex.cloud.video.v1.manifest_pb2.Manifest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["manifests", b"manifests"]) -> None: ...

global___GetVideoManifestsResponse = GetVideoManifestsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/quota/quota.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/quota/quota.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eyandex/cloud/quota/quota.proto\x12\x12yandex.cloud.quota\"?\n\x0bQuotaMetric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x03\x12\r\n\x05usage\x18\x04 \x01(\x01J\x04\x08\x02\x10\x03\"*\n\x0bMetricLimit\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x03\"\x9e\x01\n\x0cQuotaFailure\x12>\n\nviolations\x18\x02 \x03(\x0b\x32*.yandex.cloud.quota.QuotaFailure.Violation\x1aN\n\tViolation\x12/\n\x06metric\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.quota.QuotaMetric\x12\x10\n\x08required\x18\x02 \x01(\x03\x42V\n\x16yandex.cloud.api.quotaZ<github.com/yandex-cloud/go-genproto/yandex/cloud/quota;quotab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.quota.quota_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026yandex.cloud.api.quotaZ<github.com/yandex-cloud/go-genproto/yandex/cloud/quota;quota'
  _globals['_QUOTAMETRIC']._serialized_start=54
  _globals['_QUOTAMETRIC']._serialized_end=117
  _globals['_METRICLIMIT']._serialized_start=119
  _globals['_METRICLIMIT']._serialized_end=161
  _globals['_QUOTAFAILURE']._serialized_start=164
  _globals['_QUOTAFAILURE']._serialized_end=322
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_start=244
  _globals['_QUOTAFAILURE_VIOLATION']._serialized_end=322
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cloudregistry/v1/registry_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cloudregistry/v1/registry_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.cloudregistry.v1 import registry_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_registry__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.cloudregistry.v1 import ip_permission_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_ip__permission__pb2
from yandex.cloud.cloudregistry.v1 import artifact_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_artifact__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/cloudregistry/v1/registry_service.proto\x12\x1dyandex.cloud.cloudregistry.v1\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a,yandex/cloud/cloudregistry/v1/registry.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x31yandex/cloud/cloudregistry/v1/ip_permission.proto\x1a,yandex/cloud/cloudregistry/v1/artifact.proto\x1a\x1cgoogle/api/annotations.proto\"7\n\x12GetRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"v\n\x15ListRegistriesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x16ListRegistriesResponse\x12;\n\nregistries\x18\x01 \x03(\x0b\x32\'.yandex.cloud.cloudregistry.v1.Registry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x94\x05\n\x15\x43reateRegistryRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x8d\x01\n\x06labels\x18\x03 \x03(\x0b\x32@.yandex.cloud.cloudregistry.v1.CreateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12@\n\x04kind\x18\x04 \x01(\x0e\x32,.yandex.cloud.cloudregistry.v1.Registry.KindB\x04\xe8\xc7\x31\x01\x12@\n\x04type\x18\x05 \x01(\x0e\x32,.yandex.cloud.cloudregistry.v1.Registry.TypeB\x04\xe8\xc7\x31\x01\x12\x1f\n\x0b\x64\x65scription\x18\x06 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x91\x01\n\nproperties\x18\x07 \x03(\x0b\x32\x44.yandex.cloud.cloudregistry.v1.CreateRegistryRequest.PropertiesEntryB7\xf2\xc7\x31\x0e[-_0-9a-zA-Z]+\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x11\x12\t[a-zA-Z]+\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\xc3\x04\n\x15UpdateRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.cloudregistry.v1.UpdateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1f\n\x0b\x64\x65scription\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x91\x01\n\nproperties\x18\x06 \x03(\x0b\x32\x44.yandex.cloud.cloudregistry.v1.UpdateRegistryRequest.PropertiesEntryB7\xf2\xc7\x31\x0e[-_0-9a-zA-Z]+\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x11\x12\t[a-zA-Z]+\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\x81\x01\n\x17SetIpPermissionsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x43\n\x0eip_permissions\x18\x02 \x03(\x0b\x32+.yandex.cloud.cloudregistry.v1.IpPermission\"\x8f\x01\n\x1aUpdateIpPermissionsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x14ip_permission_deltas\x18\x02 \x03(\x0b\x32\x30.yandex.cloud.cloudregistry.v1.IpPermissionDelta\"=\n\x18ListIpPermissionsRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"]\n\x19ListIpPermissionsResponse\x12@\n\x0bpermissions\x18\x01 \x03(\x0b\x32+.yandex.cloud.cloudregistry.v1.IpPermission\"/\n\x18SetIpPermissionsMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"2\n\x1bUpdateIpPermissionsMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\xd2\x01\n\x14ListArtifactsRequest\x12\x1d\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12]\n\x04path\x18\x02 \x01(\tBO\xf2\xc7\x31K|[a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*(/([a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*))*\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x15ListArtifactsResponse\x12:\n\tartifacts\x18\x01 \x03(\x0b\x32\'.yandex.cloud.cloudregistry.v1.Artifact\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xae\x13\n\x0fRegistryService\x12\x96\x01\n\x03Get\x12\x31.yandex.cloud.cloudregistry.v1.GetRegistryRequest\x1a\'.yandex.cloud.cloudregistry.v1.Registry\"3\x82\xd3\xe4\x93\x02-\x12+/cloud-registry/v1/registries/{registry_id}\x12\x9a\x01\n\x04List\x12\x34.yandex.cloud.cloudregistry.v1.ListRegistriesRequest\x1a\x35.yandex.cloud.cloudregistry.v1.ListRegistriesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cloud-registry/v1/registries\x12\xb1\x01\n\x06\x43reate\x12\x34.yandex.cloud.cloudregistry.v1.CreateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2*\"\n\x16\x43reateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02\"\"\x1d/cloud-registry/v1/registries:\x01*\x12\xbf\x01\n\x06Update\x12\x34.yandex.cloud.cloudregistry.v1.UpdateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*\"\n\x16UpdateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02\x30\x32+/cloud-registry/v1/registries/{registry_id}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.cloudregistry.v1.DeleteRegistryRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*/\n\x16\x44\x65leteRegistryMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02-*+/cloud-registry/v1/registries/{registry_id}\x12\xbd\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/cloud-registry/v1/registries/{resource_id}:listAccessBindings\x12\xed\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\"=/cloud-registry/v1/registries/{resource_id}:setAccessBindings:\x01*\x12\xf9\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45\"@/cloud-registry/v1/registries/{resource_id}:updateAccessBindings:\x01*\x12\xcd\x01\n\x11ListIpPermissions\x12\x37.yandex.cloud.cloudregistry.v1.ListIpPermissionsRequest\x1a\x38.yandex.cloud.cloudregistry.v1.ListIpPermissionsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cloud-registry/v1/registries/{registry_id}:listIpPermissions\x12\xeb\x01\n\x10SetIpPermissions\x12\x36.yandex.cloud.cloudregistry.v1.SetIpPermissionsRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*1\n\x18SetIpPermissionsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x41\"</cloud-registry/v1/registries/{registry_id}:setIpPermissions:\x01*\x12\xf8\x01\n\x13UpdateIpPermissions\x12\x39.yandex.cloud.cloudregistry.v1.UpdateIpPermissionsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*4\n\x1bUpdateIpPermissionsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/cloud-registry/v1/registries/{registry_id}:updateIpPermissions:\x01*\x12\xbd\x01\n\rListArtifacts\x12\x33.yandex.cloud.cloudregistry.v1.ListArtifactsRequest\x1a\x34.yandex.cloud.cloudregistry.v1.ListArtifactsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/cloud-registry/v1/registries/{registry_id}:listArtifactsBt\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudregistry.v1.registry_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistry'
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['kind']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['kind']._serialized_options = b'\350\3071\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['type']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['properties']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['properties']._serialized_options = b'\362\3071\016[-_0-9a-zA-Z]+\202\3101\004<=64\212\3101\004<=63\262\3101\021\022\t[a-zA-Z]+\032\0041-63'
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['properties']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['properties']._serialized_options = b'\362\3071\016[-_0-9a-zA-Z]+\202\3101\004<=64\212\3101\004<=63\262\3101\021\022\t[a-zA-Z]+\032\0041-63'
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_SETIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTIPPERMISSIONSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['path']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['path']._serialized_options = b'\362\3071K|[a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*(/([a-zA-Z0-9]+(?:[._-][a-zA-Z0-9]+)*))*'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTARTIFACTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002-\022+/cloud-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\037\022\035/cloud-registry/v1/registries'
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateRegistryMetadata\022\010Registry\202\323\344\223\002\"\"\035/cloud-registry/v1/registries:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateRegistryMetadata\022\010Registry\202\323\344\223\00202+/cloud-registry/v1/registries/{registry_id}:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteRegistryMetadata\022\025google.protobuf.Empty\202\323\344\223\002-*+/cloud-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002@\022>/cloud-registry/v1/registries/{resource_id}:listAccessBindings'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B\"=/cloud-registry/v1/registries/{resource_id}:setAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002E\"@/cloud-registry/v1/registries/{resource_id}:updateAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermissions']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermissions']._serialized_options = b'\202\323\344\223\002?\022=/cloud-registry/v1/registries/{registry_id}:listIpPermissions'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermissions']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermissions']._serialized_options = b'\262\322*1\n\030SetIpPermissionsMetadata\022\025google.protobuf.Empty\202\323\344\223\002A\"</cloud-registry/v1/registries/{registry_id}:setIpPermissions:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermissions']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermissions']._serialized_options = b'\262\322*4\n\033UpdateIpPermissionsMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/cloud-registry/v1/registries/{registry_id}:updateIpPermissions:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListArtifacts']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListArtifacts']._serialized_options = b'\202\323\344\223\002;\0229/cloud-registry/v1/registries/{registry_id}:listArtifacts'
  _globals['_GETREGISTRYREQUEST']._serialized_start=433
  _globals['_GETREGISTRYREQUEST']._serialized_end=488
  _globals['_LISTREGISTRIESREQUEST']._serialized_start=490
  _globals['_LISTREGISTRIESREQUEST']._serialized_end=608
  _globals['_LISTREGISTRIESRESPONSE']._serialized_start=610
  _globals['_LISTREGISTRIESRESPONSE']._serialized_end=720
  _globals['_CREATEREGISTRYREQUEST']._serialized_start=723
  _globals['_CREATEREGISTRYREQUEST']._serialized_end=1383
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=1287
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1332
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_start=1334
  _globals['_CREATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_end=1383
  _globals['_CREATEREGISTRYMETADATA']._serialized_start=1385
  _globals['_CREATEREGISTRYMETADATA']._serialized_end=1430
  _globals['_UPDATEREGISTRYREQUEST']._serialized_start=1433
  _globals['_UPDATEREGISTRYREQUEST']._serialized_end=2012
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=1287
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1332
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_start=1334
  _globals['_UPDATEREGISTRYREQUEST_PROPERTIESENTRY']._serialized_end=1383
  _globals['_UPDATEREGISTRYMETADATA']._serialized_start=2014
  _globals['_UPDATEREGISTRYMETADATA']._serialized_end=2059
  _globals['_DELETEREGISTRYREQUEST']._serialized_start=2061
  _globals['_DELETEREGISTRYREQUEST']._serialized_end=2119
  _globals['_DELETEREGISTRYMETADATA']._serialized_start=2121
  _globals['_DELETEREGISTRYMETADATA']._serialized_end=2166
  _globals['_SETIPPERMISSIONSREQUEST']._serialized_start=2169
  _globals['_SETIPPERMISSIONSREQUEST']._serialized_end=2298
  _globals['_UPDATEIPPERMISSIONSREQUEST']._serialized_start=2301
  _globals['_UPDATEIPPERMISSIONSREQUEST']._serialized_end=2444
  _globals['_LISTIPPERMISSIONSREQUEST']._serialized_start=2446
  _globals['_LISTIPPERMISSIONSREQUEST']._serialized_end=2507
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_start=2509
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_end=2602
  _globals['_SETIPPERMISSIONSMETADATA']._serialized_start=2604
  _globals['_SETIPPERMISSIONSMETADATA']._serialized_end=2651
  _globals['_UPDATEIPPERMISSIONSMETADATA']._serialized_start=2653
  _globals['_UPDATEIPPERMISSIONSMETADATA']._serialized_end=2703
  _globals['_LISTARTIFACTSREQUEST']._serialized_start=2706
  _globals['_LISTARTIFACTSREQUEST']._serialized_end=2916
  _globals['_LISTARTIFACTSRESPONSE']._serialized_start=2918
  _globals['_LISTARTIFACTSRESPONSE']._serialized_end=3026
  _globals['_REGISTRYSERVICE']._serialized_start=3029
  _globals['_REGISTRYSERVICE']._serialized_end=5507
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MongodConfig6_0(google.protobuf.message.Message):
    """Configuration of a mongod daemon. Supported options are a limited subset of all
    options described in [MongoDB documentation](https://docs.mongodb.com/v6.0/reference/configuration-options/).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Storage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class WiredTiger(google.protobuf.message.Message):
            """Configuration of WiredTiger storage engine."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class EngineConfig(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                CACHE_SIZE_GB_FIELD_NUMBER: builtins.int
                @property
                def cache_size_gb(self) -> google.protobuf.wrappers_pb2.DoubleValue:
                    """The maximum size of the internal cache that WiredTiger will use for all data."""

                def __init__(
                    self,
                    *,
                    cache_size_gb: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> None: ...

            @typing.final
            class CollectionConfig(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _Compressor:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _CompressorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongodConfig6_0.Storage.WiredTiger.CollectionConfig._Compressor.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    COMPRESSOR_UNSPECIFIED: MongodConfig6_0.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 0
                    NONE: MongodConfig6_0.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 1
                    """No compression."""
                    SNAPPY: MongodConfig6_0.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 2
                    """The [Snappy](https://docs.mongodb.com/v6.0/reference/glossary/#term-snappy) compression."""
                    ZLIB: MongodConfig6_0.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 3
                    """The [zlib](https://docs.mongodb.com/v6.0/reference/glossary/#term-zlib) compression."""
                    ZSTD: MongodConfig6_0.Storage.WiredTiger.CollectionConfig._Compressor.ValueType  # 4
                    """The [zstd](https://docs.mongodb.com/v6.0/reference/glossary/#term-zstd) compression."""

                class Compressor(_Compressor, metaclass=_CompressorEnumTypeWrapper): ...
                COMPRESSOR_UNSPECIFIED: MongodConfig6_0.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 0
                NONE: MongodConfig6_0.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 1
                """No compression."""
                SNAPPY: MongodConfig6_0.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 2
                """The [Snappy](https://docs.mongodb.com/v6.0/reference/glossary/#term-snappy) compression."""
                ZLIB: MongodConfig6_0.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 3
                """The [zlib](https://docs.mongodb.com/v6.0/reference/glossary/#term-zlib) compression."""
                ZSTD: MongodConfig6_0.Storage.WiredTiger.CollectionConfig.Compressor.ValueType  # 4
                """The [zstd](https://docs.mongodb.com/v6.0/reference/glossary/#term-zstd) compression."""

                BLOCK_COMPRESSOR_FIELD_NUMBER: builtins.int
                block_compressor: global___MongodConfig6_0.Storage.WiredTiger.CollectionConfig.Compressor.ValueType
                """Default type of compression to use for collection data."""
                def __init__(
                    self,
                    *,
                    block_compressor: global___MongodConfig6_0.Storage.WiredTiger.CollectionConfig.Compressor.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["block_compressor", b"block_compressor"]) -> None: ...

            @typing.final
            class IndexConfig(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                PREFIX_COMPRESSION_FIELD_NUMBER: builtins.int
                @property
                def prefix_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
                    """Enables or disables [prefix compression](https://www.mongodb.com/docs/manual/reference/glossary/#std-term-prefix-compression)"""

                def __init__(
                    self,
                    *,
                    prefix_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["prefix_compression", b"prefix_compression"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["prefix_compression", b"prefix_compression"]) -> None: ...

            ENGINE_CONFIG_FIELD_NUMBER: builtins.int
            COLLECTION_CONFIG_FIELD_NUMBER: builtins.int
            INDEX_CONFIG_FIELD_NUMBER: builtins.int
            @property
            def engine_config(self) -> global___MongodConfig6_0.Storage.WiredTiger.EngineConfig:
                """Engine configuration for WiredTiger."""

            @property
            def collection_config(self) -> global___MongodConfig6_0.Storage.WiredTiger.CollectionConfig:
                """Collection configuration for WiredTiger."""

            @property
            def index_config(self) -> global___MongodConfig6_0.Storage.WiredTiger.IndexConfig:
                """Index configuration for WiredTiger"""

            def __init__(
                self,
                *,
                engine_config: global___MongodConfig6_0.Storage.WiredTiger.EngineConfig | None = ...,
                collection_config: global___MongodConfig6_0.Storage.WiredTiger.CollectionConfig | None = ...,
                index_config: global___MongodConfig6_0.Storage.WiredTiger.IndexConfig | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["collection_config", b"collection_config", "engine_config", b"engine_config", "index_config", b"index_config"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["collection_config", b"collection_config", "engine_config", b"engine_config", "index_config", b"index_config"]) -> None: ...

        @typing.final
        class Journal(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            COMMIT_INTERVAL_FIELD_NUMBER: builtins.int
            @property
            def commit_interval(self) -> google.protobuf.wrappers_pb2.Int64Value:
                """Commit interval between journal operations, in milliseconds.
                Default: 100.
                """

            def __init__(
                self,
                *,
                commit_interval: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["commit_interval", b"commit_interval"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["commit_interval", b"commit_interval"]) -> None: ...

        WIRED_TIGER_FIELD_NUMBER: builtins.int
        JOURNAL_FIELD_NUMBER: builtins.int
        @property
        def wired_tiger(self) -> global___MongodConfig6_0.Storage.WiredTiger:
            """Configuration of the WiredTiger storage engine."""

        @property
        def journal(self) -> global___MongodConfig6_0.Storage.Journal:
            """Configuration of the MongoDB [journal](https://docs.mongodb.com/v6.0/reference/glossary/#term-journal)."""

        def __init__(
            self,
            *,
            wired_tiger: global___MongodConfig6_0.Storage.WiredTiger | None = ...,
            journal: global___MongodConfig6_0.Storage.Journal | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["journal", b"journal", "wired_tiger", b"wired_tiger"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["journal", b"journal", "wired_tiger", b"wired_tiger"]) -> None: ...

    @typing.final
    class OperationProfiling(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongodConfig6_0.OperationProfiling._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            MODE_UNSPECIFIED: MongodConfig6_0.OperationProfiling._Mode.ValueType  # 0
            OFF: MongodConfig6_0.OperationProfiling._Mode.ValueType  # 1
            """The profiler is off and does not collect any data."""
            SLOW_OP: MongodConfig6_0.OperationProfiling._Mode.ValueType  # 2
            """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
            ALL: MongodConfig6_0.OperationProfiling._Mode.ValueType  # 3
            """The profiler collects data for all operations."""

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
        MODE_UNSPECIFIED: MongodConfig6_0.OperationProfiling.Mode.ValueType  # 0
        OFF: MongodConfig6_0.OperationProfiling.Mode.ValueType  # 1
        """The profiler is off and does not collect any data."""
        SLOW_OP: MongodConfig6_0.OperationProfiling.Mode.ValueType  # 2
        """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
        ALL: MongodConfig6_0.OperationProfiling.Mode.ValueType  # 3
        """The profiler collects data for all operations."""

        MODE_FIELD_NUMBER: builtins.int
        SLOW_OP_THRESHOLD_FIELD_NUMBER: builtins.int
        SLOW_OP_SAMPLE_RATE_FIELD_NUMBER: builtins.int
        mode: global___MongodConfig6_0.OperationProfiling.Mode.ValueType
        """Mode which specifies operations that should be profiled."""
        @property
        def slow_op_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The slow operation time threshold, in milliseconds. Operations that run
            for longer than this threshold are considered slow, and are processed by the profiler
            running in the SLOW_OP mode.
            """

        @property
        def slow_op_sample_rate(self) -> google.protobuf.wrappers_pb2.DoubleValue:
            """The fraction of slow operations that should be profiled or logged.
            operationProfiling.slowOpSampleRate accepts values between 0 and 1, inclusive.
            """

        def __init__(
            self,
            *,
            mode: global___MongodConfig6_0.OperationProfiling.Mode.ValueType = ...,
            slow_op_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            slow_op_sample_rate: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["slow_op_sample_rate", b"slow_op_sample_rate", "slow_op_threshold", b"slow_op_threshold"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["mode", b"mode", "slow_op_sample_rate", b"slow_op_sample_rate", "slow_op_threshold", b"slow_op_threshold"]) -> None: ...

    @typing.final
    class Network(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Compression(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _Compressor:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _CompressorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongodConfig6_0.Network.Compression._Compressor.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                COMPRESSOR_UNSPECIFIED: MongodConfig6_0.Network.Compression._Compressor.ValueType  # 0
                SNAPPY: MongodConfig6_0.Network.Compression._Compressor.ValueType  # 1
                """The [Snappy](https://docs.mongodb.com/v4.2/reference/glossary/#term-snappy) compression."""
                ZLIB: MongodConfig6_0.Network.Compression._Compressor.ValueType  # 2
                """The [zlib](https://docs.mongodb.com/v4.2/reference/glossary/#term-zlib) compression."""
                ZSTD: MongodConfig6_0.Network.Compression._Compressor.ValueType  # 3
                """The [zstd](https://docs.mongodb.com/v4.2/reference/glossary/#term-zstd) compression."""
                DISABLED: MongodConfig6_0.Network.Compression._Compressor.ValueType  # 4
                """No compression"""

            class Compressor(_Compressor, metaclass=_CompressorEnumTypeWrapper): ...
            COMPRESSOR_UNSPECIFIED: MongodConfig6_0.Network.Compression.Compressor.ValueType  # 0
            SNAPPY: MongodConfig6_0.Network.Compression.Compressor.ValueType  # 1
            """The [Snappy](https://docs.mongodb.com/v4.2/reference/glossary/#term-snappy) compression."""
            ZLIB: MongodConfig6_0.Network.Compression.Compressor.ValueType  # 2
            """The [zlib](https://docs.mongodb.com/v4.2/reference/glossary/#term-zlib) compression."""
            ZSTD: MongodConfig6_0.Network.Compression.Compressor.ValueType  # 3
            """The [zstd](https://docs.mongodb.com/v4.2/reference/glossary/#term-zstd) compression."""
            DISABLED: MongodConfig6_0.Network.Compression.Compressor.ValueType  # 4
            """No compression"""

            COMPRESSORS_FIELD_NUMBER: builtins.int
            @property
            def compressors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___MongodConfig6_0.Network.Compression.Compressor.ValueType]:
                """Specifies the default compressor(s) to use for communication between this mongod or mongos instance and:
                - other members of the deployment if the instance is part of a replica set or a sharded cluster
                - mongosh
                - drivers that support the OP_COMPRESSED message format.
                MongoDB supports the following compressors:
                """

            def __init__(
                self,
                *,
                compressors: collections.abc.Iterable[global___MongodConfig6_0.Network.Compression.Compressor.ValueType] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["compressors", b"compressors"]) -> None: ...

        MAX_INCOMING_CONNECTIONS_FIELD_NUMBER: builtins.int
        COMPRESSION_FIELD_NUMBER: builtins.int
        @property
        def max_incoming_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The maximum number of simultaneous connections that mongod will accept."""

        @property
        def compression(self) -> global___MongodConfig6_0.Network.Compression:
            """Compression settings"""

        def __init__(
            self,
            *,
            max_incoming_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            compression: global___MongodConfig6_0.Network.Compression | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["compression", b"compression", "max_incoming_connections", b"max_incoming_connections"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["compression", b"compression", "max_incoming_connections", b"max_incoming_connections"]) -> None: ...

    @typing.final
    class SetParameter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLE_FLOW_CONTROL_FIELD_NUMBER: builtins.int
        MIN_SNAPSHOT_HISTORY_WINDOW_IN_SECONDS_FIELD_NUMBER: builtins.int
        @property
        def enable_flow_control(self) -> google.protobuf.wrappers_pb2.BoolValue:
            """Enables or disables the mechanism that controls the rate at which the primary applies its writes with the
            goal of keeping the secondary members [majority committed](https://www.mongodb.com/docs/v4.2/reference/command/replSetGetStatus/#replSetGetStatus.optimes.lastCommittedOpTime)
            lag under a configurable maximum value.
            """

        @property
        def min_snapshot_history_window_in_seconds(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The minimum time window in seconds for which the storage engine keeps the snapshot history."""

        def __init__(
            self,
            *,
            enable_flow_control: google.protobuf.wrappers_pb2.BoolValue | None = ...,
            min_snapshot_history_window_in_seconds: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["enable_flow_control", b"enable_flow_control", "min_snapshot_history_window_in_seconds", b"min_snapshot_history_window_in_seconds"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["enable_flow_control", b"enable_flow_control", "min_snapshot_history_window_in_seconds", b"min_snapshot_history_window_in_seconds"]) -> None: ...

    STORAGE_FIELD_NUMBER: builtins.int
    OPERATION_PROFILING_FIELD_NUMBER: builtins.int
    NET_FIELD_NUMBER: builtins.int
    SET_PARAMETER_FIELD_NUMBER: builtins.int
    @property
    def storage(self) -> global___MongodConfig6_0.Storage:
        """`storage` section of mongod configuration."""

    @property
    def operation_profiling(self) -> global___MongodConfig6_0.OperationProfiling:
        """`operationProfiling` section of mongod configuration."""

    @property
    def net(self) -> global___MongodConfig6_0.Network:
        """`net` section of mongod configuration."""

    @property
    def set_parameter(self) -> global___MongodConfig6_0.SetParameter:
        """`SetParameter` section of mongod configuration."""

    def __init__(
        self,
        *,
        storage: global___MongodConfig6_0.Storage | None = ...,
        operation_profiling: global___MongodConfig6_0.OperationProfiling | None = ...,
        net: global___MongodConfig6_0.Network | None = ...,
        set_parameter: global___MongodConfig6_0.SetParameter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "set_parameter", b"set_parameter", "storage", b"storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "set_parameter", b"set_parameter", "storage", b"storage"]) -> None: ...

global___MongodConfig6_0 = MongodConfig6_0

@typing.final
class MongoCfgConfig6_0(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Storage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class WiredTiger(google.protobuf.message.Message):
            """Configuration of WiredTiger storage engine."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class EngineConfig(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                CACHE_SIZE_GB_FIELD_NUMBER: builtins.int
                @property
                def cache_size_gb(self) -> google.protobuf.wrappers_pb2.DoubleValue:
                    """The maximum size of the internal cache that WiredTiger will use for all data."""

                def __init__(
                    self,
                    *,
                    cache_size_gb: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["cache_size_gb", b"cache_size_gb"]) -> None: ...

            ENGINE_CONFIG_FIELD_NUMBER: builtins.int
            @property
            def engine_config(self) -> global___MongoCfgConfig6_0.Storage.WiredTiger.EngineConfig:
                """Engine configuration for WiredTiger."""

            def __init__(
                self,
                *,
                engine_config: global___MongoCfgConfig6_0.Storage.WiredTiger.EngineConfig | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["engine_config", b"engine_config"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["engine_config", b"engine_config"]) -> None: ...

        WIRED_TIGER_FIELD_NUMBER: builtins.int
        @property
        def wired_tiger(self) -> global___MongoCfgConfig6_0.Storage.WiredTiger:
            """Configuration of the WiredTiger storage engine."""

        def __init__(
            self,
            *,
            wired_tiger: global___MongoCfgConfig6_0.Storage.WiredTiger | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["wired_tiger", b"wired_tiger"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["wired_tiger", b"wired_tiger"]) -> None: ...

    @typing.final
    class OperationProfiling(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Mode:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongoCfgConfig6_0.OperationProfiling._Mode.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            MODE_UNSPECIFIED: MongoCfgConfig6_0.OperationProfiling._Mode.ValueType  # 0
            OFF: MongoCfgConfig6_0.OperationProfiling._Mode.ValueType  # 1
            """The profiler is off and does not collect any data."""
            SLOW_OP: MongoCfgConfig6_0.OperationProfiling._Mode.ValueType  # 2
            """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
            ALL: MongoCfgConfig6_0.OperationProfiling._Mode.ValueType  # 3
            """The profiler collects data for all operations."""

        class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
        MODE_UNSPECIFIED: MongoCfgConfig6_0.OperationProfiling.Mode.ValueType  # 0
        OFF: MongoCfgConfig6_0.OperationProfiling.Mode.ValueType  # 1
        """The profiler is off and does not collect any data."""
        SLOW_OP: MongoCfgConfig6_0.OperationProfiling.Mode.ValueType  # 2
        """The profiler collects data for operations that take longer than the value of [slow_op_threshold]."""
        ALL: MongoCfgConfig6_0.OperationProfiling.Mode.ValueType  # 3
        """The profiler collects data for all operations."""

        MODE_FIELD_NUMBER: builtins.int
        SLOW_OP_THRESHOLD_FIELD_NUMBER: builtins.int
        mode: global___MongoCfgConfig6_0.OperationProfiling.Mode.ValueType
        """Mode which specifies operations that should be profiled."""
        @property
        def slow_op_threshold(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The slow operation time threshold, in milliseconds. Operations that run
            for longer than this threshold are considered slow, and are processed by the profiler
            running in the SLOW_OP mode. For details see [MongoDB documentation](https://docs.mongodb.com/v6.0/reference/configuration-options/#operationProfiling.slowOpThresholdMs).
            """

        def __init__(
            self,
            *,
            mode: global___MongoCfgConfig6_0.OperationProfiling.Mode.ValueType = ...,
            slow_op_threshold: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["slow_op_threshold", b"slow_op_threshold"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["mode", b"mode", "slow_op_threshold", b"slow_op_threshold"]) -> None: ...

    @typing.final
    class Network(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_INCOMING_CONNECTIONS_FIELD_NUMBER: builtins.int
        @property
        def max_incoming_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The maximum number of simultaneous connections that mongocfg will accept."""

        def __init__(
            self,
            *,
            max_incoming_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["max_incoming_connections", b"max_incoming_connections"]) -> None: ...

    STORAGE_FIELD_NUMBER: builtins.int
    OPERATION_PROFILING_FIELD_NUMBER: builtins.int
    NET_FIELD_NUMBER: builtins.int
    @property
    def storage(self) -> global___MongoCfgConfig6_0.Storage:
        """`storage` section of mongocfg configuration."""

    @property
    def operation_profiling(self) -> global___MongoCfgConfig6_0.OperationProfiling:
        """`operationProfiling` section of mongocfg configuration."""

    @property
    def net(self) -> global___MongoCfgConfig6_0.Network:
        """`net` section of mongocfg configuration."""

    def __init__(
        self,
        *,
        storage: global___MongoCfgConfig6_0.Storage | None = ...,
        operation_profiling: global___MongoCfgConfig6_0.OperationProfiling | None = ...,
        net: global___MongoCfgConfig6_0.Network | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "storage", b"storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["net", b"net", "operation_profiling", b"operation_profiling", "storage", b"storage"]) -> None: ...

global___MongoCfgConfig6_0 = MongoCfgConfig6_0

@typing.final
class MongosConfig6_0(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Network(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Compression(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _Compressor:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _CompressorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MongosConfig6_0.Network.Compression._Compressor.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                COMPRESSOR_UNSPECIFIED: MongosConfig6_0.Network.Compression._Compressor.ValueType  # 0
                SNAPPY: MongosConfig6_0.Network.Compression._Compressor.ValueType  # 1
                """The [Snappy](https://docs.mongodb.com/v4.2/reference/glossary/#term-snappy) compression."""
                ZLIB: MongosConfig6_0.Network.Compression._Compressor.ValueType  # 2
                """The [zlib](https://docs.mongodb.com/v4.2/reference/glossary/#term-zlib) compression."""
                ZSTD: MongosConfig6_0.Network.Compression._Compressor.ValueType  # 3
                """The [zstd](https://docs.mongodb.com/v4.2/reference/glossary/#term-zstd) compression."""
                DISABLED: MongosConfig6_0.Network.Compression._Compressor.ValueType  # 4
                """No compression"""

            class Compressor(_Compressor, metaclass=_CompressorEnumTypeWrapper): ...
            COMPRESSOR_UNSPECIFIED: MongosConfig6_0.Network.Compression.Compressor.ValueType  # 0
            SNAPPY: MongosConfig6_0.Network.Compression.Compressor.ValueType  # 1
            """The [Snappy](https://docs.mongodb.com/v4.2/reference/glossary/#term-snappy) compression."""
            ZLIB: MongosConfig6_0.Network.Compression.Compressor.ValueType  # 2
            """The [zlib](https://docs.mongodb.com/v4.2/reference/glossary/#term-zlib) compression."""
            ZSTD: MongosConfig6_0.Network.Compression.Compressor.ValueType  # 3
            """The [zstd](https://docs.mongodb.com/v4.2/reference/glossary/#term-zstd) compression."""
            DISABLED: MongosConfig6_0.Network.Compression.Compressor.ValueType  # 4
            """No compression"""

            COMPRESSORS_FIELD_NUMBER: builtins.int
            @property
            def compressors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___MongosConfig6_0.Network.Compression.Compressor.ValueType]:
                """Specifies the default compressor(s) to use for communication between this mongod or mongos instance and:
                - other members of the deployment if the instance is part of a replica set or a sharded cluster
                - mongosh
                - drivers that support the OP_COMPRESSED message format.
                MongoDB supports the following compressors:
                """

            def __init__(
                self,
                *,
                compressors: collections.abc.Iterable[global___MongosConfig6_0.Network.Compression.Compressor.ValueType] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["compressors", b"compressors"]) -> None: ...

        MAX_INCOMING_CONNECTIONS_FIELD_NUMBER: builtins.int
        COMPRESSION_FIELD_NUMBER: builtins.int
        @property
        def max_incoming_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """The maximum number of simultaneous connections that mongos will accept."""

        @property
        def compression(self) -> global___MongosConfig6_0.Network.Compression:
            """Compression settings"""

        def __init__(
            self,
            *,
            max_incoming_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            compression: global___MongosConfig6_0.Network.Compression | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["compression", b"compression", "max_incoming_connections", b"max_incoming_connections"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["compression", b"compression", "max_incoming_connections", b"max_incoming_connections"]) -> None: ...

    NET_FIELD_NUMBER: builtins.int
    @property
    def net(self) -> global___MongosConfig6_0.Network:
        """Network settings for mongos."""

    def __init__(
        self,
        *,
        net: global___MongosConfig6_0.Network | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["net", b"net"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["net", b"net"]) -> None: ...

global___MongosConfig6_0 = MongosConfig6_0

@typing.final
class MongodConfigSet6_0(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MongodConfig6_0:
        """Effective mongod settings for a MongoDB 6.0 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MongodConfig6_0:
        """User-defined mongod settings for a MongoDB 6.0 cluster."""

    @property
    def default_config(self) -> global___MongodConfig6_0:
        """Default mongod configuration for a MongoDB 6.0 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MongodConfig6_0 | None = ...,
        user_config: global___MongodConfig6_0 | None = ...,
        default_config: global___MongodConfig6_0 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MongodConfigSet6_0 = MongodConfigSet6_0

@typing.final
class MongoCfgConfigSet6_0(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MongoCfgConfig6_0:
        """Effective mongocfg settings for a MongoDB 6.0 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MongoCfgConfig6_0:
        """User-defined mongocfg settings for a MongoDB 6.0 cluster."""

    @property
    def default_config(self) -> global___MongoCfgConfig6_0:
        """Default mongocfg configuration for a MongoDB 6.0 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MongoCfgConfig6_0 | None = ...,
        user_config: global___MongoCfgConfig6_0 | None = ...,
        default_config: global___MongoCfgConfig6_0 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MongoCfgConfigSet6_0 = MongoCfgConfigSet6_0

@typing.final
class MongosConfigSet6_0(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___MongosConfig6_0:
        """Effective mongos settings for a MongoDB 6.0 cluster (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___MongosConfig6_0:
        """User-defined mongos settings for a MongoDB 6.0 cluster."""

    @property
    def default_config(self) -> global___MongosConfig6_0:
        """Default mongos configuration for a MongoDB 6.0 cluster."""

    def __init__(
        self,
        *,
        effective_config: global___MongosConfig6_0 | None = ...,
        user_config: global___MongosConfig6_0 | None = ...,
        default_config: global___MongosConfig6_0 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___MongosConfigSet6_0 = MongosConfigSet6_0



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/foundation_models/v1/image_generation/image_generation_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/foundation_models/v1/image_generation/image_generation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ai.foundation_models.v1.image_generation import image_generation_pb2 as yandex_dot_cloud_dot_ai_dot_foundation__models_dot_v1_dot_image__generation_dot_image__generation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nTyandex/cloud/ai/foundation_models/v1/image_generation/image_generation_service.proto\x12\x35yandex.cloud.ai.foundation_models.v1.image_generation\x1a\x1cgoogle/api/annotations.proto\x1aLyandex/cloud/ai/foundation_models/v1/image_generation/image_generation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"\xe8\x01\n\x16ImageGenerationRequest\x12\x11\n\tmodel_uri\x18\x01 \x01(\t\x12P\n\x08messages\x18\x02 \x03(\x0b\x32>.yandex.cloud.ai.foundation_models.v1.image_generation.Message\x12i\n\x12generation_options\x18\x03 \x01(\x0b\x32M.yandex.cloud.ai.foundation_models.v1.image_generation.ImageGenerationOptions\"?\n\x17ImageGenerationResponse\x12\r\n\x05image\x18\x01 \x01(\x0c\x12\x15\n\rmodel_version\x18\x02 \x01(\t2\xef\x01\n\x1bImageGenerationAsyncService\x12\xcf\x01\n\x08Generate\x12M.yandex.cloud.ai.foundation_models.v1.image_generation.ImageGenerationRequest\x1a!.yandex.cloud.operation.Operation\"Q\xb2\xd2*\x19\x12\x17ImageGenerationResponse\x82\xd3\xe4\x93\x02.\")/foundationModels/v1/imageGenerationAsync:\x01*B\xa7\x01\n9yandex.cloud.api.ai.foundation_models.v1.image_generationZjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/image_generation;image_generationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.image_generation.image_generation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n9yandex.cloud.api.ai.foundation_models.v1.image_generationZjgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/image_generation;image_generation'
  _globals['_IMAGEGENERATIONASYNCSERVICE'].methods_by_name['Generate']._loaded_options = None
  _globals['_IMAGEGENERATIONASYNCSERVICE'].methods_by_name['Generate']._serialized_options = b'\262\322*\031\022\027ImageGenerationResponse\202\323\344\223\002.\")/foundationModels/v1/imageGenerationAsync:\001*'
  _globals['_IMAGEGENERATIONREQUEST']._serialized_start=326
  _globals['_IMAGEGENERATIONREQUEST']._serialized_end=558
  _globals['_IMAGEGENERATIONRESPONSE']._serialized_start=560
  _globals['_IMAGEGENERATIONRESPONSE']._serialized_end=623
  _globals['_IMAGEGENERATIONASYNCSERVICE']._serialized_start=626
  _globals['_IMAGEGENERATIONASYNCSERVICE']._serialized_end=865
# @@protoc_insertion_point(module_scope)
